# Configure Data Quality Controls
### On this page
  * [Ensure Data Integrity with the Quality Seal](https://help.sap.com/docs/leanix/ea/configure-data-quality-controls#ensure-data-integrity-with-the-quality-seal)
  * [Define Mandatory Attributes for Fact Sheets](https://help.sap.com/docs/leanix/ea/configure-data-quality-controls#define-mandatory-attributes-for-fact-sheets)
  * [Track Data Completeness with the Completion Score](https://help.sap.com/docs/leanix/ea/configure-data-quality-controls#track-data-completeness-with-the-completion-score)


To maintain the quality and completeness of your inventory data, configure data quality controls.
Up-to-date and accurate data is essential for effective enterprise architecture management. Fact sheet owners are responsible for maintaining fact sheet data and ensuring its quality. As an enterprise architect, you configure data quality control mechanisms based on your requirements:
  * Quality seal: Configure the quality seal to ensure the overall integrity and quality of data on fact sheets. When the quality seal is broken (based on the renewal interval or due to data changes), fact sheet owners get notified to review and update fact sheet data.
  * Mandatory attributes: Define mandatory attributes to maintain data integrity and ensure its completeness. Fact sheet owners can approve the quality seal only once these attributes are filled in.
  * Completion score: Configure the completion score to track how much of the required data has been filled out for a fact sheet.


To learn more about maintaining data quality, see [Increasing Your Data Quality](https://help.sap.com/docs/leanix/ea/increasing-your-data-quality?locale=en-US&state=PRODUCTION&version=CLOUD "Enhance data quality in SAP LeanIX with features like fact sheet completion scores, fact sheet subscriptions, mandatory fields, quality seals, and surveys. Use integrations and discovery tools for accurate, up-to-date data.").
